/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     NEG = 258,
     tABS = 259,
     tACOS = 260,
     tACOSH = 261,
     tAND = 262,
     tANS = 263,
     tASIN = 264,
     tASINH = 265,
     tATAN = 266,
     tATANH = 267,
     tCBRT = 268,
     tCHS = 269,
     tCOS = 270,
     tCOSH = 271,
     tDDB = 272,
     tEXP = 273,
     tFRAC = 274,
     tFV = 275,
     tINT = 276,
     tLN = 277,
     tLOG10 = 278,
     tLOG2 = 279,
     tNOT = 280,
     tOR = 281,
     tPI = 282,
     tPMT = 283,
     tPV = 284,
     tRAND = 285,
     tRATE = 286,
     tSIN = 287,
     tSINH = 288,
     tSLN = 289,
     tSQRT = 290,
     tSYD = 291,
     tTAN = 292,
     tTANH = 293,
     tTERM = 294,
     tU16 = 295,
     tU32 = 296,
     tXNOR = 297,
     tXOR = 298,
     tRCL = 299,
     tSTO = 300,
     tCLR = 301,
     tINUMBER = 302,
     tDNUMBER = 303,
     POS = 304
   };
#endif
/* Tokens.  */
#define NEG 258
#define tABS 259
#define tACOS 260
#define tACOSH 261
#define tAND 262
#define tANS 263
#define tASIN 264
#define tASINH 265
#define tATAN 266
#define tATANH 267
#define tCBRT 268
#define tCHS 269
#define tCOS 270
#define tCOSH 271
#define tDDB 272
#define tEXP 273
#define tFRAC 274
#define tFV 275
#define tINT 276
#define tLN 277
#define tLOG10 278
#define tLOG2 279
#define tNOT 280
#define tOR 281
#define tPI 282
#define tPMT 283
#define tPV 284
#define tRAND 285
#define tRATE 286
#define tSIN 287
#define tSINH 288
#define tSLN 289
#define tSQRT 290
#define tSYD 291
#define tTAN 292
#define tTANH 293
#define tTERM 294
#define tU16 295
#define tU32 296
#define tXNOR 297
#define tXOR 298
#define tRCL 299
#define tSTO 300
#define tCLR 301
#define tINUMBER 302
#define tDNUMBER 303
#define POS 304




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 38 "./lr_parser.y"
{
  int int_t[MP_SIZE];
}
/* Line 1489 of yacc.c.  */
#line 151 "lr_parser.tab.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE lrlval;

